@@ -101,12 +101,12 @@ def read_args(args):
                         nargs=2)
 
     parser.add_argument("--sat",
-                        help="add or substract the saturation of a "
+                        help="add or subtract the saturation of a "
                         "colorscheme [colorscheme, sat] (0, 1)",
                         nargs=2)
 
     parser.add_argument("--brt",
-                        help="add or substract the brightness of a "
+                        help="add or subtract the brightness of a "
                         "colorscheme [colorscheme, brt] (0, 255)",
                         nargs=2)
 
@@ -123,10 +123,15 @@ def read_args(args):
                         action="store_true")
 
     parser.add_argument("--noreload",
-                        help="Skip reloading other software after"
+                        help="Skip reloading other software after "
                         "applying colorscheme",
                         action="store_true")
 
+    parser.add_argument("--noterminal",
+                        help="Skip changing the terminal colorscheme "
+                        "using pywal Skip changing colors in terminals",
+                        action="store_true")
+
     return parser.parse_args()
 
 
@@ -156,6 +161,9 @@ def process_args(args):
     if args.light:
         settings["light_theme"] = "true"
 
+    if args.noterminal:
+        settings["terminal"] = "false"
+
     if args.n:
         settings["set_wallpaper"] = "false"
 
@@ -217,9 +225,11 @@ def process_args(args):
     if args.a:
         add_action = files.add_template if args.t \
                      else themer.create_theme
-        for x in args.a:
-            if path.isfile(glob.glob(x)[0]):
-                add_action(glob.glob(x)[0])
+        for pattern in args.a:
+            for filename in glob.glob(pattern):
+                if path.isfile(filename):
+                    add_action(filename)
+
         exit(0)
 
     if args.c:
