@@ -1,9 +1,8 @@
-from gi.repository import Gtk, Gdk
 from gi import require_version
 from ..data.config import settings, write_conf
 from pywal import colors
-# making sure it uses v3.0
 require_version("Gtk",  "3.0")
+from gi.repository import Gtk, Gdk  # noqa: E402
 
 PAD = 10
 
@@ -105,6 +104,14 @@ class OptionsGrid(Gtk.Grid):
         )
         self.lbl_reload = Gtk.Label("Reload other software")
 
+        self.terminal_switch = Gtk.Switch()
+        self.terminal_switch.connect(
+            "notify::active",
+            self.on_activate,
+            "terminal"
+        )
+        self.lbl_terminal = Gtk.Label("Change terminal colors")
+
         # edit cmd
         self.editor_lbl = Gtk.Label("Open optional files with:")
         self.editor_txt = Gtk.Entry()
@@ -154,6 +161,9 @@ class OptionsGrid(Gtk.Grid):
         self.switch_grid.attach(self.lbl_reload, 5, 4, 3, 1)
         self.switch_grid.attach(self.reload_switch, 9, 4, 1, 1)
 
+        self.switch_grid.attach(self.lbl_terminal, 1, 5, 3, 1)
+        self.switch_grid.attach(self.terminal_switch, 4, 5, 1, 1)
+
         # Active Grid attach
         self.active_grid.attach(self.backend_lbl, 1, 1, 1, 1)
         self.active_grid.attach(self.backend_combo, 2, 1, 1, 1)
@@ -205,6 +215,8 @@ class OptionsGrid(Gtk.Grid):
             .set_active(settings.getboolean("auto_adjust", False))
         self.reload_switch\
             .set_active(settings.getboolean("reload", True))
+        self.terminal_switch\
+            .set_active(settings.getboolean("terminal", True))
 
         self.editor_txt\
             .set_text(settings.get("editor", "urxvt -e vim"))
@@ -229,6 +241,7 @@ class OptionsGrid(Gtk.Grid):
 
     def on_txt_change(self, gtk_entry, *gparam):
         settings[gparam[0]] = gtk_entry.get_text()
+        self.save_button.set_sensitive(True)
 
     def on_save_button(self,  button):
         write_conf()
