@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-__ScriptVersion="0.1.5";
+__ScriptVersion="0.1.6";
 
 if [ -n "${XDG_CONFIG_HOME}" ]; then
   CONFIG="${XDG_CONFIG_HOME}"
@@ -32,6 +32,7 @@ usage()
   -o   Install openbox templates
   -t   Install tint2 template
   -g   Install gtk template
+  -G   Install linea nord gtk template
   -i   Install icon-set
   -r   Install rofi template
   -I   Install i3 template
@@ -154,6 +155,23 @@ install_gtk()
   echo ":: FlatColor gtk themes install done."
 }
 
+install_alternative_gtk()
+{
+  echo "Installing linea nord gtk themes";
+  cp -r ./linea-nord-color "${LOCAL}/themes/" && \
+
+  cp --remove-destination ./linea-nord-color/gtk-2.0/gtkrc.base "${TEMPLATE_DIR}/gtk2-nord.base" && \
+    ln -sf "${LOCAL}/themes/linea-nord-color/gtk-2.0/gtkrc" "${TEMPLATE_DIR}/gtk2-nord" && \
+	echo ":: gtk2 theme done" "${TEMPLATE_DIR}/gtk2-nord";
+
+  mkdir -p "${THEMES_DIR}" && \
+	  cp --remove-destination ./linea-nord-color/dark.css.base "${TEMPLATE_DIR}/linea-nord.css.base" && \
+	  ln -sf "${LOCAL}/themes/linea-nord-color/general/dark.css" "${TEMPLATE_DIR}/linea-nord.css" && \
+	  ln -sf "${LOCAL}/themes/linea-nord-color" "${THEMES_DIR}/linea-nord-color" && \
+
+  echo ":: Linea Nord Color gtk themes install done."
+}
+
 install_icons()
 {
   echo "Installing icon pack";
@@ -165,7 +183,7 @@ install_icons()
 install_openbox()
 {
   echo "Installing openbox themes";
-  cp --remove-destination -r ./openbox/colorbamboo/* "${LOCAL}/themes/colorbamboo"
+  cp --remove-destination -r ./openbox/colorbamboo/* "${LOCAL}/themes/colorbamboo/openbox-3/"
 
   mkdir -p "${THEMES_DIR}"
 
@@ -228,7 +246,7 @@ install_qtile()
   fi
   echo ":: qtile theme install done" && \
   echo ":: generated colors are available using colors[0-15] list in place of hex values." &&\
-  echo ":: remember to edit your config.py colors to use the wpg color scheme where appropiate";
+  echo ":: remember to edit your config.py colors to use the wpg color scheme where appropriate";
 }
 
 
@@ -244,7 +262,7 @@ clean_up()
 
 getargs()
 {
-  while getopts "H:bhvotgiIprdBq" opt
+  while getopts "H:bhvotgGiIprdBq" opt
   do
     case $opt in
       h)
@@ -258,6 +276,7 @@ getargs()
       o) openbox="true" ;;
       i)   icons="true" ;;
       g)     gtk="true" ;;
+	  G)     gtk_alt="true" ;;
       t)   tint2="true" ;;
       r)    rofi="true" ;;
       I)      i3="true" ;;
@@ -286,6 +305,7 @@ main()
   [[ "$tint2" == "true" ]] && install_tint2;
   [[ "$rofi" == "true" ]] && install_rofi;
   [[ "$gtk" == "true" ]] && install_gtk;
+  [[ "$gtk_alt" == "true" ]] && install_alternative_gtk;
   [[ "$icons" == "true" ]] && install_icons;
   [[ "$polybar" == "true" ]] && install_polybar;
   [[ "$i3" == "true" ]] && install_i3;
